#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>
#include <strings.h>
#include <string.h>
#include "p9p.h"

void
sysfatal(char *fmt, ...)
{
	va_list arg;

	va_start(arg, fmt);
	vfprintf(stderr, fmt, arg);
	va_end(arg);
	exit(1);
}

static char*
qtoken(char *s, char *sep)
{
	int quoting;
	char *t;

	quoting = 0;
	t = s;	/* s is output string, t is input string */
	while (*t != 0 && (quoting || strchr(sep, *t) == nil)) {
		if (*t != '\'') {
			*s++ = *t++;
			continue;
		}
		/* *t is a quote */
		if (!quoting) {
			quoting = 1;
			t++;
			continue;
		}
		/* quoting and we're on a quote */
		if (t[1] != '\'') {
			/* end of quoted section; absorb closing quote */
			t++;
			quoting = 0;
			continue;
		}
		/* doubled quote; fold one quote into two */
		t++;
		*s++ = *t++;
	}
	if (*s != '\0') {
		*s = '\0';
		if(t == s)
			t++;
	}
	return t;
}

int
tokenize(char *s, char **args, int maxargs)
{
	int nargs;
	static char qsep[] = " \t\r\n";

	for (nargs=0; nargs<maxargs; nargs++) {
		while (*s != '\0' && strchr(qsep, *s))
			s++;
		if (*s == '\0')
			break;
		args[nargs] = s;
		s = qtoken(s, qsep);
	}

	return nargs;
}

